---
last_modified_on: "2020-04-19"
delivery_guarantee: "at_least_once"
component_title: "Clickhouse"
description: "The Vector `clickhouse` sink batches `log` events to Clickhouse via the `HTTP` Interface."
event_types: ["log"]
function_category: "transmit"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+clickhouse%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "clickhouse|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sinks/clickhouse.rs
status: "beta"
title: "Clickhouse Sink"
unsupported_operating_systems: []
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import SVG from 'react-inlinesvg';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `clickhouse` sink
[batches](#buffers--batches) [`log`][docs.data-model.log] events to
[Clickhouse][urls.clickhouse] via the [`HTTP` Interface][urls.clickhouse_http].

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sinks/clickhouse.md.erb
-->

## Requirements

<Alert icon={false} type="danger" className="list--icons list--icons--warnings">

* [Clickhouse][urls.clickhouse] version `>= 1.1.54378` is required.

</Alert>

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "clickhouse" # required
  inputs = ["my-source-id"] # required
  database = "mydatabase" # optional, no default
  healthcheck = true # optional, default
  host = "http://localhost:8123" # required
  table = "mytable" # required

  # requests
  compression = "none" # optional, default
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "clickhouse" # required
  inputs = ["my-source-id"] # required
  database = "mydatabase" # optional, no default
  healthcheck = true # optional, default
  host = "http://localhost:8123" # required
  table = "mytable" # required

  # Auth
  auth.strategy = "basic" # required
  auth.password = "${CLICKHOUSE_PASSWORD}" # required, required when strategy = "basic"
  auth.user = "${CLICKHOUSE_USERNAME}" # required, required when strategy = "basic"

  # Batch
  batch.max_size = 1049000 # optional, default, bytes
  batch.timeout_secs = 1 # optional, default, seconds

  # Buffer
  buffer.type = "memory" # optional, default
  buffer.max_events = 500 # optional, default, events, relevant when type = "memory"
  buffer.max_size = 104900000 # required, bytes, required when type = "disk"
  buffer.when_full = "block" # optional, default

  # Encoding
  encoding.except_fields = ["timestamp", "message", "host"] # optional, no default
  encoding.only_fields = ["timestamp", "message", "host"] # optional, no default
  encoding.timestamp_format = "rfc3339" # optional, default

  # Request
  request.in_flight_limit = 5 # optional, default, requests
  request.rate_limit_duration_secs = 1 # optional, default, seconds
  request.rate_limit_num = 5 # optional, default
  request.retry_attempts = -1 # optional, default
  request.retry_initial_backoff_secs = 1 # optional, default, seconds
  request.retry_max_duration_secs = 10 # optional, default, seconds
  request.timeout_secs = 30 # optional, default, seconds

  # requests
  compression = "none" # optional, default

  # TLS
  tls.ca_path = "/path/to/certificate_authority.crt" # optional, no default
  tls.crt_path = "/path/to/host_certificate.crt" # optional, no default
  tls.key_pass = "${KEY_PASS_ENV_VAR}" # optional, no default
  tls.key_path = "/path/to/host_certificate.key" # optional, no default
  tls.verify_certificate = true # optional, default
  tls.verify_hostname = true # optional, default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"auth"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### auth

Options for the authentication strategy.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"basic":"The [basic authentication strategy][urls.basic_auth]."}}
  examples={["basic"]}
  groups={[]}
  name={"strategy"}
  path={"auth"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### strategy

The authentication strategy to use.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${CLICKHOUSE_PASSWORD}","password"]}
  groups={[]}
  name={"password"}
  path={"auth"}
  relevantWhen={{"strategy":"basic"}}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### password

The basic authentication password.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${CLICKHOUSE_USERNAME}","username"]}
  groups={[]}
  name={"user"}
  path={"auth"}
  relevantWhen={{"strategy":"basic"}}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### user

The basic authentication user name.




</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"batch"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### batch

Configures the sink batching behavior.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={1049000}
  enumValues={null}
  examples={[1049000]}
  groups={[]}
  name={"max_size"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"bytes"}
  warnings={[]}
  >

#### max_size

The maximum size of a batch, in bytes, before it is flushed.

 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"timeout_secs"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum age of a batch before it is flushed.

 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"buffer"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### buffer

Configures the sink specific buffer behavior.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={"memory"}
  enumValues={{"memory":"Stores the sink's buffer in memory. This is more performant, but less durable. Data will be lost if Vector is restarted forcefully.","disk":"Stores the sink's buffer on disk. This is less performant, but durable. Data will not be lost between restarts."}}
  examples={["memory","disk"]}
  groups={[]}
  name={"type"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### type

The buffer's type and storage mechanism.




</Field>
<Field
  common={true}
  defaultValue={500}
  enumValues={null}
  examples={[500]}
  groups={[]}
  name={"max_events"}
  path={"buffer"}
  relevantWhen={{"type":"memory"}}
  required={false}
  templateable={false}
  type={"int"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum number of [events][docs.data-model] allowed in the buffer.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[104900000]}
  groups={[]}
  name={"max_size"}
  path={"buffer"}
  relevantWhen={{"type":"disk"}}
  required={true}
  templateable={false}
  type={"int"}
  unit={"bytes"}
  warnings={[]}
  >

#### max_size

The maximum size of the buffer on the disk.

 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
<Field
  common={false}
  defaultValue={"block"}
  enumValues={{"block":"Applies back pressure when the buffer is full. This prevents data loss, but will cause data to pile up on the edge.","drop_newest":"Drops new data as it's received. This data is lost. This should be used when performance is the highest priority."}}
  examples={["block","drop_newest"]}
  groups={[]}
  name={"when_full"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### when_full

The behavior when the buffer becomes full.




</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"encoding"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### encoding

Configures the encoding specific sink behavior.



<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","message","host"]]}
  groups={[]}
  name={"except_fields"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

#### except_fields

Prevent the sink from encoding the specified labels.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","message","host"]]}
  groups={[]}
  name={"only_fields"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

#### only_fields

Limit the sink to only encoding the specified labels.




</Field>
<Field
  common={true}
  defaultValue={"rfc3339"}
  enumValues={{"rfc3339":"Format as an RFC3339 string","unix":"Format as a unix timestamp, can be parsed as a Clickhouse DateTime"}}
  examples={["rfc3339","unix"]}
  groups={[]}
  name={"timestamp_format"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### timestamp_format

How to format event timestamps.




</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["mydatabase"]}
  groups={[]}
  name={"database"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### database

The database that contains the stable that data will be inserted into.




</Field>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"healthcheck"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### healthcheck

Enables/disables the sink healthcheck upon start.

 See [Health Checks](#health-checks) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["http://localhost:8123"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### host

The host url of the [Clickhouse][urls.clickhouse] server.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["mytable"]}
  groups={[]}
  name={"table"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### table

The table that data will be inserted into.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"request"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### request

Configures the sink request behavior.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={[]}
  name={"in_flight_limit"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"requests"}
  warnings={[]}
  >

#### in_flight_limit

The maximum number of in-flight requests allowed at any given time.

 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"rate_limit_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### rate_limit_duration_secs

The time window, in seconds, used for the [`rate_limit_num`](#rate_limit_num) option.

 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={[]}
  name={"rate_limit_num"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  warnings={[]}
  >

#### rate_limit_num

The maximum number of requests allowed within the [`rate_limit_duration_secs`](#rate_limit_duration_secs)
time window.

 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={false}
  defaultValue={-1}
  enumValues={null}
  examples={[-1]}
  groups={[]}
  name={"retry_attempts"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  warnings={[]}
  >

#### retry_attempts

The maximum number of retries to make for failed requests.

 See [Retry Policy](#retry-policy) for more info.


</Field>
<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"retry_initial_backoff_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_initial_backoff_secs

The amount of time to wait before attempting the first retry for a failed
request. Once, the first retry has failed the fibonacci sequence will be used
to select future backoffs.




</Field>
<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"retry_max_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_max_duration_secs

The maximum amount of time, in seconds, to wait between retries.




</Field>
<Field
  common={true}
  defaultValue={30}
  enumValues={null}
  examples={[30]}
  groups={[]}
  name={"timeout_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum time a request can take before being aborted. It is highly
recommended that you do not lower value below the service's internal timeout,
as this could create orphaned requests, pile on retries, and result in
duplicate data downstream.

 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={"none"}
  enumValues={{"none":"The payload will not be compressed.","gzip":"The payload will be compressed in [Gzip][urls.gzip] format before being sent."}}
  examples={["none","gzip"]}
  groups={[]}
  name={"compression"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### compression

The compression strategy used to compress the encoded event data before
outputting.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"tls"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### tls

Configures the TLS options for connections from this sink.



<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/certificate_authority.crt"]}
  groups={[]}
  name={"ca_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### ca_path

Absolute path to an additional CA certificate file, in DER or PEM format
(X.509).




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.crt"]}
  groups={[]}
  name={"crt_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### crt_path

Absolute path to a certificate file used to identify this connection, in DER or
PEM format (X.509) or PKCS#12. If this is set and is not a PKCS#12 archive,
`key_path` must also be set.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["${KEY_PASS_ENV_VAR}","PassWord1"]}
  groups={[]}
  name={"key_pass"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_pass

Pass phrase used to unlock the encrypted key file. This has no effect unless
`key_path` is set.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.key"]}
  groups={[]}
  name={"key_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_path

Absolute path to a certificate key file used to identify this connection, in
DER or PEM format (PKCS#8). If this is set, [`crt_path`](#crt_path) must also be set.




</Field>
<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"verify_certificate"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[{"visibility_level":"option","text":"Setting this to `false` means the certificate will be loaded and checked for validity, but the handshake will not attempt to verify the certificate. Do NOT set this to `false` unless you understand the risks of not verifying the remote certificate.","option_name":"verify_certificate"}]}
  >

#### verify_certificate

If `true` (the default), Vector will validate the TLS certificate of the remote
host.




</Field>
<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"verify_hostname"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

#### verify_hostname

If `true` (the default), Vector will validate the configured remote host name
against the remote host's TLS certificate. Do NOT set this to `false` unless
you understand the risks of not verifying the remote hostname.




</Field>
</Fields>

</Field>
</Fields>


## How It Works

### Buffers & Batches

<SVG src="/img/buffers-and-batches-serial.svg" />

The `clickhouse` sink buffers & batches data as
shown in the diagram above. You'll notice that Vector treats these concepts
differently, instead of treating them as global concepts, Vector treats them
as sink specific concepts. This isolates sinks, ensuring services disruptions
are contained and [delivery guarantees][docs.guarantees] are honored.

*Batches* are flushed when 1 of 2 conditions are met:

1. The batch age meets or exceeds the configured [`timeout_secs`](#timeout_secs).
2. The batch size meets or exceeds the configured [`max_size`](#max_size).

*Buffers* are controlled via the [`buffer.*`](#buffer) options.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.
If the health check fails an error will be logged and Vector will proceed to
start.

#### Require Health Checks

If you'd like to exit immediately upon a health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

#### Disable Health Checks

If you'd like to disable health checks for this sink you can set the
`healthcheck` option to `false`.

### Rate Limits

Vector offers a few levers to control the rate and volume of requests to the
downstream service. Start with the [`rate_limit_duration_secs`](#rate_limit_duration_secs) and
`rate_limit_num` options to ensure Vector does not exceed the specified
number of requests in the specified window. You can further control the pace at
which this window is saturated with the [`in_flight_limit`](#in_flight_limit) option, which
will guarantee no more than the specified number of requests are in-flight at
any given time.

Please note, Vector's defaults are carefully chosen and it should be rare that
you need to adjust these. If you found a good reason to do so please share it
with the Vector team by [opening an issue][urls.new_clickhouse_sink_issue].

### Retry Policy

Vector will retry failed requests (status == `429`, >= `500`, and != `501`).
Other responses will _not_ be retried. You can control the number of retry
attempts and backoff rate with the [`retry_attempts`](#retry_attempts) and
`retry_backoff_secs` options.

### TLS

Vector uses [Openssl][urls.openssl] for TLS protocols for it's battle-tested
and reliable security. You can enable and adjust TLS behavior via the [`tls.*`](#tls)
options.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.data-model]: /docs/about/data-model/
[docs.guarantees]: /docs/about/guarantees/
[urls.basic_auth]: https://en.wikipedia.org/wiki/Basic_access_authentication
[urls.clickhouse]: https://clickhouse.yandex/
[urls.clickhouse_http]: https://clickhouse.yandex/docs/en/interfaces/http/
[urls.gzip]: https://www.gzip.org/
[urls.new_clickhouse_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+clickhouse
[urls.openssl]: https://www.openssl.org/
