---
last_modified_on: "2020-04-06"
delivery_guarantee: "at_least_once"
component_title: "InfluxDB Metrics"
description: "The Vector `influxdb_metrics` sink batches `metric` events to InfluxDB using v1 or v2 HTTP API."
event_types: ["metric"]
function_category: "transmit"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+influxdb_metrics%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "influxdb_metrics|[\"metric\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sinks/influxdb_metrics.rs
status: "beta"
title: "InfluxDB Metrics Sink"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `influxdb_metrics` sink
[batches](#buffers--batches) [`metric`][docs.data-model.metric] events to
[InfluxDB][urls.influxdb] using [v1][urls.influxdb_http_api_v1] or
[v2][urls.influxdb_http_api_v2] HTTP API.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sinks/influxdb_metrics.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="v1"
  values={[{"label":"v1","value":"v1"},{"label":"v1 (adv)","value":"v1-adv"},{"label":"v2","value":"v2"},{"label":"v2 (adv)","value":"v2-adv"}]}>
<TabItem value="v1">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "influxdb_metrics" # required
  inputs = ["my-source-id"] # required
  endpoint = "https://us-west-2-1.aws.cloud1.influxdata.com" # required
  namespace = "service" # required
  database = "vector-database" # required
  healthcheck = true # optional, default

  # Auth
  password = "${INFLUXDB_PASSWORD}" # optional, no default
  username = "todd" # optional, no default

  # Persistence
  consistency = "any" # optional, no default
  retention_policy_name = "autogen" # optional, no default
```

</TabItem>
<TabItem value="v1-adv">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "influxdb_metrics" # required
  inputs = ["my-source-id"] # required
  endpoint = "https://us-west-2-1.aws.cloud1.influxdata.com" # required
  namespace = "service" # required
  database = "vector-database" # required
  healthcheck = true # optional, default

  # Auth
  password = "${INFLUXDB_PASSWORD}" # optional, no default
  username = "todd" # optional, no default

  # Batch
  batch.max_events = 20 # optional, default, events
  batch.timeout_secs = 1 # optional, default, seconds

  # Persistence
  consistency = "any" # optional, no default
  retention_policy_name = "autogen" # optional, no default

  # Request
  request.in_flight_limit = 5 # optional, default, requests
  request.rate_limit_duration_secs = 1 # optional, default, seconds
  request.rate_limit_num = 5 # optional, default
  request.retry_attempts = -1 # optional, default
  request.retry_initial_backoff_secs = 1 # optional, default, seconds
  request.retry_max_duration_secs = 10 # optional, default, seconds
  request.timeout_secs = 60 # optional, default, seconds
```

</TabItem>
<TabItem value="v2">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "influxdb_metrics" # required
  inputs = ["my-source-id"] # required
  endpoint = "https://us-west-2-1.aws.cloud2.influxdata.com" # required
  namespace = "service" # required
  bucket = "vector-bucket" # required
  healthcheck = true # optional, default

  # Auth
  org = "my-org" # required
  token = "${INFLUXDB_TOKEN}" # required
```

</TabItem>
<TabItem value="v2-adv">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "influxdb_metrics" # required
  inputs = ["my-source-id"] # required
  endpoint = "https://us-west-2-1.aws.cloud2.influxdata.com" # required
  namespace = "service" # required
  bucket = "vector-bucket" # required
  healthcheck = true # optional, default

  # Auth
  org = "my-org" # required
  token = "${INFLUXDB_TOKEN}" # required

  # Batch
  batch.max_events = 20 # optional, default, events
  batch.timeout_secs = 1 # optional, default, seconds

  # Request
  request.in_flight_limit = 5 # optional, default, requests
  request.rate_limit_duration_secs = 1 # optional, default, seconds
  request.rate_limit_num = 5 # optional, default
  request.retry_attempts = -1 # optional, default
  request.retry_initial_backoff_secs = 1 # optional, default, seconds
  request.retry_max_duration_secs = 10 # optional, default, seconds
  request.timeout_secs = 60 # optional, default, seconds
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["http://localhost:8086/","https://us-west-2-1.aws.cloud1.influxdata.com","https://us-west-2-1.aws.cloud2.influxdata.com"]}
  groups={["v1","v2"]}
  name={"endpoint"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### endpoint

InfluxDB endpoint to send metrics to.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["service"]}
  groups={["v1","v2"]}
  name={"namespace"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### namespace

A prefix that will be added to all metric names.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["my-org","33f2cff0a28e5b63"]}
  groups={["v2"]}
  name={"org"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### org

Specifies the destination organization for writes into InfluxDB 2.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${INFLUXDB_PASSWORD}","influxdb4ever"]}
  groups={["v1"]}
  name={"password"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### password

Sets the password for authentication if you’ve enabled authentication for the
write into InfluxDB 1.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${INFLUXDB_TOKEN}","ef8d5de700e7989468166c40fc8a0ccd"]}
  groups={["v2"]}
  name={"token"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### token

[Authentication token][urls.influxdb_authentication_token] for InfluxDB 2.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["todd","vector-source"]}
  groups={["v1"]}
  name={"username"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### username

Sets the username for authentication if you’ve enabled authentication for the
write into InfluxDB 1.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={["v1","v2"]}
  name={"batch"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### batch

Configures the sink batching behavior.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={20}
  enumValues={null}
  examples={[20]}
  groups={["v1","v2"]}
  name={"max_events"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum size of a batch, in events, before it is flushed.




</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={["v1","v2"]}
  name={"timeout_secs"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum age of a batch before it is flushed.




</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["vector-bucket","4d2225e4d3d49f75"]}
  groups={["v2"]}
  name={"bucket"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### bucket

The destination bucket for writes into InfluxDB 2.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["vector-database","iot-store"]}
  groups={["v1"]}
  name={"database"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### database

Sets the target database for the write into InfluxDB 1.




</Field>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={["v1","v2"]}
  name={"healthcheck"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### healthcheck

Enables/disables the sink healthcheck upon start.

 See [Health Checks](#health-checks) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["any","one","quorum","all"]}
  groups={["v1"]}
  name={"consistency"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### consistency

Sets the write consistency for the point for InfluxDB 1.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["autogen","one_day_only"]}
  groups={["v1"]}
  name={"retention_policy_name"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### retention_policy_name

Sets the target retention policy for the write into InfluxDB 1.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={["v1","v2"]}
  name={"request"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### request

Configures the sink request behavior.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={["v1","v2"]}
  name={"in_flight_limit"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"requests"}
  warnings={[]}
  >

#### in_flight_limit

The maximum number of in-flight requests allowed at any given time.

 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={["v1","v2"]}
  name={"rate_limit_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### rate_limit_duration_secs

The time window, in seconds, used for the [`rate_limit_num`](#rate_limit_num) option.

 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={["v1","v2"]}
  name={"rate_limit_num"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  warnings={[]}
  >

#### rate_limit_num

The maximum number of requests allowed within the [`rate_limit_duration_secs`](#rate_limit_duration_secs)
time window.

 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={false}
  defaultValue={-1}
  enumValues={null}
  examples={[-1]}
  groups={["v1","v2"]}
  name={"retry_attempts"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  warnings={[]}
  >

#### retry_attempts

The maximum number of retries to make for failed requests.

 See [Retry Policy](#retry-policy) for more info.


</Field>
<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={["v1","v2"]}
  name={"retry_initial_backoff_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_initial_backoff_secs

The amount of time to wait before attempting the first retry for a failed
request. Once, the first retry has failed the fibonacci sequence will be used
to select future backoffs.




</Field>
<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={["v1","v2"]}
  name={"retry_max_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_max_duration_secs

The maximum amount of time, in seconds, to wait between retries.




</Field>
<Field
  common={true}
  defaultValue={60}
  enumValues={null}
  examples={[60]}
  groups={["v1","v2"]}
  name={"timeout_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum time a request can take before being aborted. It is highly
recommended that you do not lower value below the service's internal timeout,
as this could create orphaned requests, pile on retries, and result in
duplicate data downstream.




</Field>
</Fields>

</Field>
</Fields>


## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.
If the health check fails an error will be logged and Vector will proceed to
start.

#### Require Health Checks

If you'd like to exit immediately upon a health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

#### Disable Health Checks

If you'd like to disable health checks for this sink you can set the
`healthcheck` option to `false`.

### Metric Types

InfluxDB uses [line protocol][urls.influxdb_line_protocol] to write data points. It is a text-based format that provides the measurement, tag set, field set, and timestamp of a data point.

The following matrix outlines how Vector metric types are mapped into InfluxDB Line Protocol fields.

| Vector Metrics | Line Protocol Fields                             | Example                                                                                                                                                   |
|----------------|--------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------|
| Counter        | value                                            | `ns.total,metric_type=counter value=1.5 1542182950000000011`                                                                                              |
| Gauge          | value                                            | `ns.meter,metric_type=gauge,normal_tag=value,true_tag=true value=-1.5 1542182950000000011`                                                                |
| Set            | value                                            | `ns.users,metric_type=set,normal_tag=value,true_tag=true value=2 154218295000000001`                                                                      |
| Histogram      | buckets, count, sum                              | `ns.requests,metric_type=histogram,normal_tag=value,true_tag=true bucket_1=1i,bucket_2.1=2i,bucket_3=3i,count=6i,sum=12.5 1542182950000000011`            |
| Summary        | quantiles, count, sum                            | `ns.requests_sum,metric_type=summary,normal_tag=value,true_tag=true count=6i,quantile_0.01=1.5,quantile_0.5=2,quantile_0.99=3,sum=12 1542182950000000011` |
| Distribution   | min, max, median, avg, sum, count, quantile 0.95 | `ns.sparse_stats,metric_type=distribution avg=3,count=10,max=4,median=3,min=1,quantile_0.95=4,sum=30 1542182950000000011`                                 |

### Rate Limits

Vector offers a few levers to control the rate and volume of requests to the
downstream service. Start with the [`rate_limit_duration_secs`](#rate_limit_duration_secs) and
`rate_limit_num` options to ensure Vector does not exceed the specified
number of requests in the specified window. You can further control the pace at
which this window is saturated with the [`in_flight_limit`](#in_flight_limit) option, which
will guarantee no more than the specified number of requests are in-flight at
any given time.

Please note, Vector's defaults are carefully chosen and it should be rare that
you need to adjust these. If you found a good reason to do so please share it
with the Vector team by [opening an issue][urls.new_influxdb_metrics_sink_issue].

### Retry Policy

Vector will retry failed requests (status == `429`, >= `500`, and != `501`).
Other responses will _not_ be retried. You can control the number of retry
attempts and backoff rate with the [`retry_attempts`](#retry_attempts) and
`retry_backoff_secs` options.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.metric]: /docs/about/data-model/metric/
[urls.influxdb]: https://www.influxdata.com/products/influxdb-overview/
[urls.influxdb_authentication_token]: https://v2.docs.influxdata.com/v2.0/security/tokens/
[urls.influxdb_http_api_v1]: https://docs.influxdata.com/influxdb/latest/tools/api/#write-http-endpoint
[urls.influxdb_http_api_v2]: https://v2.docs.influxdata.com/v2.0/api/#tag/Write
[urls.influxdb_line_protocol]: https://v2.docs.influxdata.com/v2.0/reference/syntax/line-protocol/
[urls.new_influxdb_metrics_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+influxdb_metrics
