---
last_modified_on: "2020-04-08"
delivery_guarantee: "at_least_once"
component_title: "Kafka"
description: "The Vector `kafka` source ingests data through Kafka and outputs `log` events."
event_types: ["log"]
function_category: "collect"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+kafka%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "kafka|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/kafka.rs
status: "beta"
title: "Kafka Source"
unsupported_operating_systems: []
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `kafka` source
ingests data through [Kafka][urls.kafka] and outputs
[`log`][docs.data-model.log] events.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/kafka.md.erb
-->

## Requirements

<Alert icon={false} type="danger" className="list--icons list--icons--warnings">

* [Kafka][urls.kafka] version `>= 0.8` is required.

</Alert>

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sources.my_source_id]
  type = "kafka" # required
  bootstrap_servers = "10.14.22.123:9092,10.14.23.332:9092" # required
  group_id = "consumer-group-name" # required
  key_field = "message_key" # optional, no default
  topics = ["^(prefix1|prefix2)-.+", "topic-1", "topic-2"] # required
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sources.my_source_id]
  # General
  type = "kafka" # required
  auto_offset_reset = "largest" # optional, default
  bootstrap_servers = "10.14.22.123:9092,10.14.23.332:9092" # required
  fetch_wait_max_ms = 100 # optional, default, milliseconds
  group_id = "consumer-group-name" # required
  key_field = "message_key" # optional, no default
  session_timeout_ms = 10000 # optional, default, milliseconds
  socket_timeout_ms = 60000 # optional, default, milliseconds
  topics = ["^(prefix1|prefix2)-.+", "topic-1", "topic-2"] # required

  # Advanced
  librdkafka_options."client.id" = "${ENV_VAR}" # example
  librdkafka_options."fetch.error.backoff.ms" = "1000" # example
  librdkafka_options."socket.send.buffer.bytes" = "100" # example

  # TLS
  tls.enabled = false # optional, default
  tls.ca_path = "/path/to/certificate_authority.crt" # optional, no default
  tls.crt_path = "/path/to/host_certificate.crt" # optional, no default
  tls.key_pass = "${KEY_PASS_ENV_VAR}" # optional, no default
  tls.key_path = "/path/to/host_certificate.key" # optional, no default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"librdkafka_options"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### librdkafka_options

Advanced options. See [librdkafka documentation][urls.librdkafka_config] for
details.



<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[{"client.id":"${ENV_VAR}"},{"fetch.error.backoff.ms":"1000"},{"socket.send.buffer.bytes":"100"}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"librdkafka_options"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[field-name]`

The options and their values. Accepts `string` values.




</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={"largest"}
  enumValues={null}
  examples={["smallest","earliest","beginning","largest","latest","end","error"]}
  groups={[]}
  name={"auto_offset_reset"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### auto_offset_reset

If offsets for consumer group do not exist, set them using this strategy.
[librdkafka documentation][urls.librdkafka_config] for `auto.offset.reset`
option for explanation.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["10.14.22.123:9092,10.14.23.332:9092"]}
  groups={[]}
  name={"bootstrap_servers"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### bootstrap_servers

A comma-separated list of host and port pairs that are the addresses of the
Kafka brokers in a "bootstrap" Kafka cluster that a Kafka client connects to
initially to bootstrap itself.




</Field>
<Field
  common={false}
  defaultValue={100}
  enumValues={null}
  examples={[50,100]}
  groups={[]}
  name={"fetch_wait_max_ms"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"milliseconds"}
  warnings={[]}
  >

### fetch_wait_max_ms

Maximum time the broker may wait to fill the response.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["consumer-group-name"]}
  groups={[]}
  name={"group_id"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### group_id

The consumer group name to be used to consume events from Kafka.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["message_key"]}
  groups={[]}
  name={"key_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### key_field

The log field name to use for the Kafka message key. If unspecified, the key
would not be added to the log event. If the message has null key, then this
field would not be added to the log event.




</Field>
<Field
  common={false}
  defaultValue={10000}
  enumValues={null}
  examples={[5000,10000]}
  groups={[]}
  name={"session_timeout_ms"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"milliseconds"}
  warnings={[]}
  >

### session_timeout_ms

The Kafka session timeout in milliseconds.




</Field>
<Field
  common={false}
  defaultValue={60000}
  enumValues={null}
  examples={[30000,60000]}
  groups={[]}
  name={"socket_timeout_ms"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"milliseconds"}
  warnings={[]}
  >

### socket_timeout_ms

Default timeout for network requests.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["^(prefix1|prefix2)-.+","topic-1","topic-2"]]}
  groups={[]}
  name={"topics"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### topics

The Kafka topics names to read events from. Regex is supported if the topic
begins with `^`.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"tls"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### tls

Configures the TLS options for connections from this sink.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={false}
  enumValues={null}
  examples={[false,true]}
  groups={[]}
  name={"enabled"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

#### enabled

Enable TLS during connections to the remote.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/certificate_authority.crt"]}
  groups={[]}
  name={"ca_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### ca_path

Absolute path to an additional CA certificate file, in DER or PEM format
(X.509).




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.crt"]}
  groups={[]}
  name={"crt_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### crt_path

Absolute path to a certificate file used to identify this connection, in DER or
PEM format (X.509) or PKCS#12. If this is set and is not a PKCS#12 archive,
`key_path` must also be set.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["${KEY_PASS_ENV_VAR}","PassWord1"]}
  groups={[]}
  name={"key_pass"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_pass

Pass phrase used to unlock the encrypted key file. This has no effect unless
`key_path` is set.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.key"]}
  groups={[]}
  name={"key_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_path

Absolute path to a certificate key file used to identify this connection, in
DER or PEM format (PKCS#8). If this is set, [`crt_path`](#crt_path) must also be set.




</Field>
</Fields>

</Field>
</Fields>

## Fields

```javascript title="example log event"
{
  // ...
  "message": "Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100",
  "timestamp": "2019-11-01T21:15:47+00:00"
  // ...
}
```

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100"]}
  groups={[]}
  name={"message"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### message

The raw event message, unaltered.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  groups={[]}
  name={"timestamp"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"timestamp"}
  unit={null}
  warnings={[]}
  >

### timestamp

The exact time the event was ingested.




</Field>
</Fields>

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### TLS

Vector uses [Openssl][urls.openssl] for TLS protocols for it's battle-tested
and reliable security. You can enable and adjust TLS behavior via the [`tls.*`](#tls)
options.

### librdkafka

The `kafka` source uses [`librdkafka`][urls.librdkafka] under the hood. This
is a battle tested, performant, and reliabile library that facilitates
communication with Kafka. And because Vector produces static MUSL builds,
this dependency is packaged with Vector, meaning you do not need to install it.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[urls.kafka]: https://kafka.apache.org/
[urls.librdkafka]: https://github.com/edenhill/librdkafka
[urls.librdkafka_config]: https://github.com/edenhill/librdkafka/blob/master/CONFIGURATION.md
[urls.openssl]: https://www.openssl.org/
