---
last_modified_on: "2020-04-19"
$schema: "/.meta/.schemas/guides.json"
title: "Send metrics from Prometheus to Statsd"
description: "A simple guide to send metrics from Prometheus to Statsd in just a few minutes."
author_github: https://github.com/binarylogic
cover_label: "Prometheus to Statsd Integration"
tags: ["type: tutorial","domain: sources","domain: sinks","source: prometheus","sink: statsd"]
hide_pagination: true
---

import ConfigExample from '@site/src/components/ConfigExample';
import DaemonDiagram from '@site/src/components/DaemonDiagram';
import InstallationCommand from '@site/src/components/InstallationCommand';
import Jump from '@site/src/components/Jump';
import Steps from '@site/src/components/Steps';

Metrics are an _essential_ part of observing any
service; without them you are flying blind. But collecting and analyzing them
can be a real challenge -- especially at scale. Not only do you need to solve
the basic task of collecting your metrics, but you must do it
in a reliable, performant, and robust manner. Nothing is more frustrating than
having your metrics pipeline fall on it's face during an
outage, or even worse, disrupt more important services!

Fear not! In this guide we'll show you how to send send metrics from [Prometheus][urls.prometheus] to [Statsd][urls.statsd]
and build a metrics pipeline that will be the backbone of
your observability strategy.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/guides/integrate/sources/prometheus/statsd.md.erb
-->

## Background

### What is Prometheus?

[Prometheus][urls.prometheus] is a pull-based monitoring system that scrapes metrics from configured endpoints, stores them efficiently, and supports a powerful query language to compose dynamic information from a variety of otherwise unrelated data points.

### What is Statsd?

[StatsD][urls.statsd] is a standard and, by extension, a set of tools that can be used to send, collect, and aggregate custom metrics from any application. Originally, StatsD referred to a daemon written by [Etsy][urls.etsy] in Node.

## Strategy

### How This Guide Works

We'll be using [Vector][urls.vector_website] to accomplish this task. Vector
is a [popular][urls.vector_stars] [open-source][urls.vector_repo] utility for
building observability pipelines. It's written in [Rust][urls.rust], making it
lightweight, [ultra-fast][urls.vector_performance] and highly reliable. And
we'll be deploying Vector as a
[daemon][docs.strategies#daemon].

The [daemon deployment strategy][docs.strategies#daemon] is designed for data
collection on a single host. Vector runs in the background, in its own process,
collecting _all_ data for that host.
For this guide, Vector will receive data from
Prometheus via Vector's
[`prometheus`][docs.sources.prometheus].
The following diagram demonstrates how it works.

<DaemonDiagram
  platformName={null}
  sourceName={"prometheus"}
  sinkName={"statsd"} />

### What We'll Accomplish

To be clear, here's everything we'll accomplish in this short guide:

<ul className="list--icons list--icons--checks list--indent">
  <li>
    Scrape one or more Prometheus endpoints.
    <ul>
      <li>Ingest all Prometheus metric types.</li>
      <li>Automatically parse metrics into a lossless interoperable data model.</li>
    </ul>
  </li>
  <li>
    Stream metrics over a StatsD UDP protocol.
    <ul>
      <li>Automatically aggregate metrics at the edge for improved performance.</li>
    </ul>
  </li>
  <li className="list--icons--arrow text--pink text--bold">All in just a few minutes!</li>
</ul>

## Tutorial

<Steps headingDepth={3}>
<ol>
<li>

### Install Vector

<InstallationCommand />

</li>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"vector.toml"}
  sourceName={"prometheus"}
  sinkName={"statsd"} />

</li>
<li>

### Start Vector

```bash
vector --config vector.toml
```

That's it! Simple and to the point. Hit `ctrl+c` to exit.

</li>
</ol>
</Steps>

## Next Steps

Vector is _powerful_ utility and we're just scratching the surface in this
guide. Here are a few pages we recommend that demonstrate the power and
flexibility of Vector:

<Jump to="https://github.com/timberio/vector" leftIcon="github" target="_blank">
  <div className="title">Vector Github repo <span className="badge badge--primary"><i className="feather icon-star"></i> 4k</span></div>
  <div className="sub-title">Vector is free and open-source!</div>
</Jump>

<Jump to="/guides/getting-started/" leftIcon="book">
  <div className="title">Vector getting started series</div>
  <div className="sub-title">Go from zero to production in under 10 minutes!</div>
</Jump>

<Jump to="/docs/about/what-is-vector/" leftIcon="book">
  <div className="title">Vector documentation</div>
  <div className="sub-title">Thoughtful, detailed docs that respect your time.</div>
</Jump>


[docs.sources.prometheus]: /docs/reference/sources/prometheus/
[docs.strategies#daemon]: /docs/setup/deployment/strategies/#daemon
[urls.etsy]: https://www.etsy.com
[urls.prometheus]: https://prometheus.io/
[urls.rust]: https://www.rust-lang.org/
[urls.statsd]: https://github.com/statsd/statsd
[urls.vector_performance]: https://vector.dev/#performance
[urls.vector_repo]: https://github.com/timberio/vector
[urls.vector_stars]: https://github.com/timberio/vector/stargazers
[urls.vector_website]: https://vector.dev
